pub trait ExecutionState:
Storage
+ RuntimeObjectResolver
+ ObjectFundsResolver { }Expand description
Interface with the store necessary to execute a programmable transaction
pub trait ExecutionState:
Storage
+ RuntimeObjectResolver
+ ObjectFundsResolver { }Interface with the store necessary to execute a programmable transaction