pub trait ExecutionState: StorageView + SuiResolver {
// Required method
fn as_child_resolver(&self) -> &dyn ChildObjectResolver;
}Expand description
Interface with the store necessary to execute a programmable transaction
pub trait ExecutionState: StorageView + SuiResolver {
// Required method
fn as_child_resolver(&self) -> &dyn ChildObjectResolver;
}Interface with the store necessary to execute a programmable transaction